import time
import csv
from datetime import datetime
import winsound
import urx

def global_test(axis):
    # Routine for testing accuracy of global movement
    rob = urx.Robot("192.168.0.215")

    v = 0.07 # m/s
    a = 0.1 # m/s^2

    pose = rob.getl()

    # positions: (0), 0.5, 1, 1.1, 1, 0.5, 0, -0.5, -1, -1.1, -1, -0.5, 0
    #distances =[0.300, 0.300, 0.100, -0.100, -0.300, -0.300, -0.300, -0.300, -0.100, 0.100, 0.300, 0.300]
    #distances =[0.300, 0.100, -0.100, -0.300, -0.300, -0.300, -0.300, -0.100, 0.100, 0.300, 0.300, 0.300] # specific for z test
    distances =[0.200, 0.200, 0.020, -0.020, -0.200, -0.200, -0.200, -0.200, -0.020, 0.020, 0.200, 0.200] # specific for y test centre


    positionx = [0]*(len(distances)+1)
    positiony = [0]*(len(distances)+1)
    positionz = [0]*(len(distances)+1)
    positionA = [0]*(len(distances)+1)
    positionB = [0]*(len(distances)+1)
    positionC = [0]*(len(distances)+1)

    times = [0]*(len(distances)+1)

    targetpositionx = [0]*(len(distances)+1)
    targetpositiony = [0]*(len(distances)+1)
    targetpositionz = [0]*(len(distances)+1)
    targetpositionA = [0]*(len(distances)+1)
    targetpositionB = [0]*(len(distances)+1)
    targetpositionC = [0]*(len(distances)+1)

    #initial measurements
    input("Press Enter to measure")
    positionx[0] = rob.getl()[0]
    positiony[0] = rob.getl()[1]
    positionz[0] = rob.getl()[2]
    positionA[0] = rob.getl()[3]
    positionB[0] = rob.getl()[4]
    positionC[0] = rob.getl()[5]

    targetpositionx[0] = pose[0]
    targetpositiony[0] = pose[1]
    targetpositionz[0] = pose[2]
    targetpositionA[0] = pose[3]
    targetpositionB[0] = pose[4]
    targetpositionC[0] = pose[5]
    times[0] = datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')


    i = 1
    try:
        for l in distances:
            input("Press Enter to move")
            pose[axis] += l
            rob.movep(pose, acc=a, vel=v, wait=False)
            input("Press Enter to measure")
            targetpositionx[i] = pose[0]
            targetpositiony[i] = pose[1]
            targetpositionz[i] = pose[2]
            targetpositionA[i] = pose[3]
            targetpositionB[i] = pose[4]
            targetpositionC[i] = pose[5]

            positionx[i] = rob.getl()[0]
            positiony[i] = rob.getl()[1]
            positionz[i] = rob.getl()[2]
            positionA[i] = rob.getl()[3]
            positionB[i] = rob.getl()[4]
            positionC[i] = rob.getl()[5]
            times[i] = datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')
            i += 1

        namestring = 'global' + datetime.fromtimestamp(time.time()).strftime('%Y-%m-%d_%H%M%S') + '.csv'
        with open(namestring, 'w', newline='') as csvfile:
            spamwriter = csv.writer(csvfile, delimiter=',', quotechar='|', quoting=csv.QUOTE_MINIMAL)
            spamwriter.writerow(times)
            spamwriter.writerow(targetpositionx)
            spamwriter.writerow(targetpositiony)
            spamwriter.writerow(targetpositionz)
            spamwriter.writerow(targetpositionA)
            spamwriter.writerow(targetpositionB)
            spamwriter.writerow(targetpositionC)

            spamwriter.writerow(positionx)
            spamwriter.writerow(positiony)
            spamwriter.writerow(positionz)
            spamwriter.writerow(positionA)
            spamwriter.writerow(positionB)
            spamwriter.writerow(positionC)

    finally:
        rob.close()



def microstep_test(axis,steps):
    # Routine for testing accuracy of microsteps
    rob = urx.Robot("192.168.0.215")

    l = 0.00002 # m
    v = 0.07 # m/s
    a = 0.1 # m/s^2

    pose = rob.getl()
    positionx = [0]*(steps+1)
    positiony = [0]*(steps+1)
    positionz = [0]*(steps+1)
    positionA = [0]*(steps+1)
    positionB = [0]*(steps+1)
    positionC = [0]*(steps+1)

    times = [0]*(steps+1)
    targetpositionx = [0]*(steps+1)
    targetpositiony = [0]*(steps+1)
    targetpositionz = [0]*(steps+1)
    targetpositionA = [0]*(steps+1)
    targetpositionB = [0]*(steps+1)
    targetpositionC = [0]*(steps+1)


    #initial measurements
    input("Press Enter to measure")
    positionx[0] = rob.getl()[0]
    positiony[0] = rob.getl()[1]
    positionz[0] = rob.getl()[2]
    positionA[0] = rob.getl()[3]
    positionB[0] = rob.getl()[4]
    positionC[0] = rob.getl()[5]

    targetpositionx[0] = pose[0]
    targetpositiony[0] = pose[1]
    targetpositionz[0] = pose[2]
    targetpositionA[0] = pose[3]
    targetpositionB[0] = pose[4]
    targetpositionC[0] = pose[5]
    times[0] = datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')

    try:
        for i in range(1,steps+1):
            input("Press Enter to move")
            pose[axis] += l
            rob.movep(pose, acc=a, vel=v, wait=False)
            time.sleep(5)
            winsound.Beep(440,400)
            targetpositionx[i] = pose[0]
            targetpositiony[i] = pose[1]
            targetpositionz[i] = pose[2]
            targetpositionA[i] = pose[3]
            targetpositionB[i] = pose[4]
            targetpositionC[i] = pose[5]

            positionx[i] = rob.getl()[0]
            positiony[i] = rob.getl()[1]
            positionz[i] = rob.getl()[2]
            positionA[i] = rob.getl()[3]
            positionB[i] = rob.getl()[4]
            positionC[i] = rob.getl()[5]
            print("ready to measure", i)
            times[i] = datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')

        namestring = 'microstep' + datetime.fromtimestamp(time.time()).strftime('%Y-%m-%d_%H%M%S') + '.csv'
        with open(namestring, 'w', newline='') as csvfile:
            spamwriter = csv.writer(csvfile, delimiter=',', quotechar='|', quoting=csv.QUOTE_MINIMAL)
            spamwriter.writerow(times)
            spamwriter.writerow(targetpositionx)
            spamwriter.writerow(targetpositiony)
            spamwriter.writerow(targetpositionz)
            spamwriter.writerow(targetpositionA)
            spamwriter.writerow(targetpositionB)
            spamwriter.writerow(targetpositionC)

            spamwriter.writerow(positionx)
            spamwriter.writerow(positiony)
            spamwriter.writerow(positionz)
            spamwriter.writerow(positionA)
            spamwriter.writerow(positionB)
            spamwriter.writerow(positionC)

    finally:
        rob.close()

def testmoves():
    rob = urx.Robot("192.168.0.90")
    pose = rob.getl()
    print(pose)

if __name__ == "__main__":
    testmoves()